@@ -6,13 +6,13 @@
 ;; Homepage: https://github.com/emacscollective/epkg-marginalia
 ;; Keywords: tools
 
-;; Package-Version: 1.1.2
-;; Package-Revision: v1.1.2-0-ga42de3acf215
+;; Package-Version: 1.1.3
+;; Package-Revision: v1.1.3-0-g1fda65cebc0d
 ;; Package-Requires: (
 ;;     (emacs     "28.1")
 ;;     (compat    "30.1")
 ;;     (epkg       "4.1")
-;;     (marginalia "2.7"))
+;;     (marginalia "2.9"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -50,11 +50,12 @@
 (require 'borg nil t)
 
 (eval-when-compile (require 'package))
-(declare-function package-load-all-descriptors "package" ())
+(declare-function package-load-all-descriptors "package-activate" ())
 (declare-function package-read-all-archive-contents "package" ())
 (declare-function package--from-builtin "package" (bi-desc))
-(declare-function package-version-join "package" (vlist))
-(declare-function package-installed-p "package" (package &optional min-version))
+(declare-function package-version-join "package-activate" (vlist))
+(declare-function package-installed-p "package-activate"
+                  (package &optional min-version))
 (defvar package--builtins)
 (defvar package--initialized)
 (defvar package-alist)
